@@ -7,7 +7,7 @@ use rustc_hash::FxHashMap;
 
 use uv_normalize::{ExtraName, GroupName, PackageName};
 use uv_pep508::{ExtraOperator, MarkerEnvironment, MarkerExpression, MarkerOperator, MarkerTree};
-use uv_pypi_types::{ConflictItem, ConflictPackage, Conflicts, Inference};
+use uv_pypi_types::{ConflictItem, ConflictKind, Conflicts, Inference};
 
 use crate::ResolveError;
 
@@ -173,9 +173,10 @@ impl UniversalMarker {
     /// This may simplify the conflicting marker component of this universal
     /// marker.
     pub(crate) fn assume_conflict_item(&mut self, item: &ConflictItem) {
-        match *item.conflict() {
-            ConflictPackage::Extra(ref extra) => self.assume_extra(item.package(), extra),
-            ConflictPackage::Group(ref group) => self.assume_group(item.package(), group),
+        match *item.kind() {
+            ConflictKind::Extra(ref extra) => self.assume_extra(item.package(), extra),
+            ConflictKind::Group(ref group) => self.assume_group(item.package(), group),
+            ConflictKind::Project => self.assume_project(item.package()),
         }
         self.pep508 = self.marker.without_extras();
     }
@@ -186,18 +187,45 @@ impl UniversalMarker {
     /// This may simplify the conflicting marker component of this universal
     /// marker.
     pub(crate) fn assume_not_conflict_item(&mut self, item: &ConflictItem) {
-        match *item.conflict() {
-            ConflictPackage::Extra(ref extra) => self.assume_not_extra(item.package(), extra),
-            ConflictPackage::Group(ref group) => self.assume_not_group(item.package(), group),
+        match *item.kind() {
+            ConflictKind::Extra(ref extra) => self.assume_not_extra(item.package(), extra),
+            ConflictKind::Group(ref group) => self.assume_not_group(item.package(), group),
+            ConflictKind::Project => self.assume_not_project(item.package()),
         }
         self.pep508 = self.marker.without_extras();
     }
 
+    /// Assumes that the "production" dependencies for the given project are
+    /// activated.
+    ///
+    /// This may simplify the conflicting marker component of this universal
+    /// marker.
+    fn assume_project(&mut self, package: &PackageName) {
+        let extra = encode_project(package);
+        self.marker = self
+            .marker
+            .simplify_extras_with(|candidate| *candidate == extra);
+        self.pep508 = self.marker.without_extras();
+    }
+
+    /// Assumes that the "production" dependencies for the given project are
+    /// not activated.
+    ///
+    /// This may simplify the conflicting marker component of this universal
+    /// marker.
+    fn assume_not_project(&mut self, package: &PackageName) {
+        let extra = encode_project(package);
+        self.marker = self
+            .marker
+            .simplify_not_extras_with(|candidate| *candidate == extra);
+        self.pep508 = self.marker.without_extras();
+    }
+
     /// Assumes that a given extra for the given package is activated.
     ///
     /// This may simplify the conflicting marker component of this universal
     /// marker.
-    pub(crate) fn assume_extra(&mut self, package: &PackageName, extra: &ExtraName) {
+    fn assume_extra(&mut self, package: &PackageName, extra: &ExtraName) {
         let extra = encode_package_extra(package, extra);
         self.marker = self
             .marker
@@ -209,7 +237,7 @@ impl UniversalMarker {
     ///
     /// This may simplify the conflicting marker component of this universal
     /// marker.
-    pub(crate) fn assume_not_extra(&mut self, package: &PackageName, extra: &ExtraName) {
+    fn assume_not_extra(&mut self, package: &PackageName, extra: &ExtraName) {
         let extra = encode_package_extra(package, extra);
         self.marker = self
             .marker
@@ -221,7 +249,7 @@ impl UniversalMarker {
     ///
     /// This may simplify the conflicting marker component of this universal
     /// marker.
-    pub(crate) fn assume_group(&mut self, package: &PackageName, group: &GroupName) {
+    fn assume_group(&mut self, package: &PackageName, group: &GroupName) {
         let extra = encode_package_group(package, group);
         self.marker = self
             .marker
@@ -233,7 +261,7 @@ impl UniversalMarker {
     ///
     /// This may simplify the conflicting marker component of this universal
     /// marker.
-    pub(crate) fn assume_not_group(&mut self, package: &PackageName, group: &GroupName) {
+    fn assume_not_group(&mut self, package: &PackageName, group: &GroupName) {
         let extra = encode_package_group(package, group);
         self.marker = self
             .marker
@@ -277,6 +305,7 @@ impl UniversalMarker {
     pub(crate) fn evaluate<P, E, G>(
         self,
         env: &MarkerEnvironment,
+        projects: impl Iterator<Item = P>,
         extras: impl Iterator<Item = (P, E)>,
         groups: impl Iterator<Item = (P, G)>,
     ) -> bool
@@ -285,12 +314,18 @@ impl UniversalMarker {
         E: Borrow<ExtraName>,
         G: Borrow<GroupName>,
     {
+        let projects = projects.map(|package| encode_project(package.borrow()));
         let extras =
             extras.map(|(package, extra)| encode_package_extra(package.borrow(), extra.borrow()));
         let groups =
             groups.map(|(package, group)| encode_package_group(package.borrow(), group.borrow()));
-        self.marker
-            .evaluate(env, &extras.chain(groups).collect::<Vec<ExtraName>>())
+        self.marker.evaluate(
+            env,
+            &projects
+                .chain(extras)
+                .chain(groups)
+                .collect::<Vec<ExtraName>>(),
+        )
     }
 
     /// Returns true if the marker always evaluates to true if the given set of extras is activated.
@@ -392,12 +427,23 @@ impl ConflictMarker {
     /// Create a conflict marker that is true only when the given extra or
     /// group (for a specific package) is activated.
     pub fn from_conflict_item(item: &ConflictItem) -> Self {
-        match *item.conflict() {
-            ConflictPackage::Extra(ref extra) => Self::extra(item.package(), extra),
-            ConflictPackage::Group(ref group) => Self::group(item.package(), group),
+        match *item.kind() {
+            ConflictKind::Extra(ref extra) => Self::extra(item.package(), extra),
+            ConflictKind::Group(ref group) => Self::group(item.package(), group),
+            ConflictKind::Project => Self::project(item.package()),
         }
     }
 
+    /// Create a conflict marker that is true only when the production
+    /// dependencies for the given package are activated.
+    pub fn project(package: &PackageName) -> Self {
+        let operator = uv_pep508::ExtraOperator::Equal;
+        let name = uv_pep508::MarkerValueExtra::Extra(encode_project(package));
+        let expr = uv_pep508::MarkerExpression::Extra { operator, name };
+        let marker = MarkerTree::expression(expr);
+        Self { marker }
+    }
+
     /// Create a conflict marker that is true only when the given extra for the
     /// given package is activated.
     pub fn extra(package: &PackageName, extra: &ExtraName) -> Self {
@@ -504,9 +550,10 @@ impl std::fmt::Debug for ConflictMarker {
 
 /// Encodes the given conflict into a valid `extra` value in a PEP 508 marker.
 fn encode_conflict_item(conflict: &ConflictItem) -> ExtraName {
-    match conflict.conflict() {
-        ConflictPackage::Extra(extra) => encode_package_extra(conflict.package(), extra),
-        ConflictPackage::Group(group) => encode_package_group(conflict.package(), group),
+    match conflict.kind() {
+        ConflictKind::Extra(extra) => encode_package_extra(conflict.package(), extra),
+        ConflictKind::Group(group) => encode_package_group(conflict.package(), group),
+        ConflictKind::Project => encode_project(conflict.package()),
     }
 }
 
@@ -535,8 +582,17 @@ fn encode_package_group(package: &PackageName, group: &GroupName) -> ExtraName {
     ExtraName::from_owned(format!("group-{package_len}-{package}-{group}")).unwrap()
 }
 
+/// Encodes the given project package name into a valid `extra` value in a PEP
+/// 508 marker.
+fn encode_project(package: &PackageName) -> ExtraName {
+    // See `encode_package_extra`, the same considerations apply here.
+    let package_len = package.as_str().len();
+    ExtraName::from_owned(format!("project-{package_len}-{package}")).unwrap()
+}
+
 #[derive(Debug)]
 enum ParsedRawExtra<'a> {
+    Project { package: &'a str },
     Extra { package: &'a str, extra: &'a str },
     Group { package: &'a str, group: &'a str },
 }
@@ -553,13 +609,13 @@ impl<'a> ParsedRawExtra<'a> {
         let Some((kind, tail)) = raw.split_once('-') else {
             return Err(mkerr(
                 raw_extra,
-                "expected to find leading `extra-` or `group-`",
+                "expected to find leading `package`, `extra-` or `group-`",
             ));
         };
         let Some((len, tail)) = tail.split_once('-') else {
             return Err(mkerr(
                 raw_extra,
-                "expected to find `{number}-` after leading `extra-` or `group-`",
+                "expected to find `{number}-` after leading `package-`, `extra-` or `group-`",
             ));
         };
         let len = len.parse::<usize>().map_err(|_| {
@@ -577,22 +633,28 @@ impl<'a> ParsedRawExtra<'a> {
                 ),
             ));
         };
-        if !tail.starts_with('-') {
-            return Err(mkerr(
-                raw_extra,
-                format!("expected `-` after package name `{package}`"),
-            ));
-        }
-        let tail = &tail[1..];
         match kind {
-            "extra" => Ok(ParsedRawExtra::Extra {
-                package,
-                extra: tail,
-            }),
-            "group" => Ok(ParsedRawExtra::Group {
-                package,
-                group: tail,
-            }),
+            "project" => Ok(ParsedRawExtra::Project { package }),
+            "extra" | "group" => {
+                if !tail.starts_with('-') {
+                    return Err(mkerr(
+                        raw_extra,
+                        format!("expected `-` after package name `{package}`"),
+                    ));
+                }
+                let tail = &tail[1..];
+                if kind == "extra" {
+                    Ok(ParsedRawExtra::Extra {
+                        package,
+                        extra: tail,
+                    })
+                } else {
+                    Ok(ParsedRawExtra::Group {
+                        package,
+                        group: tail,
+                    })
+                }
+            }
             _ => Err(mkerr(
                 raw_extra,
                 format!("unrecognized kind `{kind}` (must be `extra` or `group`)"),
@@ -608,6 +670,7 @@ impl<'a> ParsedRawExtra<'a> {
             }
         })?;
         match self {
+            Self::Project { .. } => Ok(ConflictItem::from(package)),
             Self::Extra { extra, .. } => {
                 let extra = ExtraName::from_str(extra).map_err(|name_error| {
                     ResolveError::InvalidValueInConflictMarker {
@@ -631,6 +694,7 @@ impl<'a> ParsedRawExtra<'a> {
 
     fn package(&self) -> &'a str {
         match self {
+            Self::Project { package, .. } => package,
             Self::Extra { package, .. } => package,
             Self::Group { package, .. } => package,
         }
@@ -719,6 +783,26 @@ pub(crate) fn resolve_conflicts(
                         }
                     }
                 }
+
+                // Search for the conflict item as a project.
+                if conflict_item.extra().is_none() && conflict_item.group().is_none() {
+                    let package = conflict_item.package();
+                    let encoded = encode_project(package);
+                    if encoded == *name {
+                        match operator {
+                            ExtraOperator::Equal => {
+                                or.and(*conflict_marker);
+                                found = true;
+                                break;
+                            }
+                            ExtraOperator::NotEqual => {
+                                or.and(conflict_marker.negate());
+                                found = true;
+                                break;
+                            }
+                        }
+                    }
+                }
             }
 
             // If we didn't find the marker in the list of known conflicts, assume it's always
